[![Build Status](https://travis-ci.org/shlomikushchi/Simple-Pastebin-Parser.svg?branch=master)](https://travis-ci.org/shlomikushchi/Simple-Pastebin-Parser)

# Simple-Pastebin-Parser

this is a simpler parser for the pastebin.com website.

it will iterate posts and parse their elements using lxml

installation:
---
`pip install simple-pastebin-parser`

  Release notes:
===

v0.1.0 - P.O.C
---
initial proof of concept. nothing special, just doing the dirty work of parsing the posts.

how to execute:
1. create a virtual env of python 3.6
2. install requirements
3. run python poc.py


v0.2.5 (2020-03-07)
------------------

* integration with travis.ci


v0.2.6 (2020-03-07)
------------------

* changing the POC code to work with installed pypi package

v0.3.0 (2020-03-07)
------------------

* created the Post() object for pastebin posts
* ability to stream data
